{
 description = "docman is a document management tool";

  # Nixpkgs / NixOS version to use.
  inputs.nixpkgs.url = "nixpkgs/nixos-23.05";

  outputs = { self, nixpkgs }:
    let

      # to work with older version of flakes
      lastModifiedDate = self.lastModifiedDate or self.lastModified or "19700101";

      rootPath = ./.;

      # System types to support.
      supportedSystems = [ "x86_64-linux" "x86_64-darwin" "aarch64-linux" "aarch64-darwin" ];

      # Helper function to generate an attrset '{ x86_64-linux = f "x86_64-linux"; ... }'.
      forAllSystems = nixpkgs.lib.genAttrs supportedSystems;

      # Nixpkgs instantiated for supported system types.
      nixpkgsFor = forAllSystems (system: import nixpkgs { inherit system; });
      
      versionTool = nixpkgs.lib.fetchzip {
        url = "https://gitlab.schukai.com/oss/utilities/version/-/archive/0.5.0/version-0.5.0.tar.gz";
        # You'll need to provide the correct hash here.
        # sha256 = "0000000000000000000000000000000000000000000000000000";
      };      

    in
    {

      # Provide some binary packages for selected system types.
      packages = forAllSystems (system:
        let
          pkgs = nixpkgsFor.${system};
          buildDate = builtins.date "%Y%m%d" (builtins.fromJSON lastModifiedDate);
          version = builtins.readFile "${versionTool}/version print --git";
        in
        {
          docman = pkgs.buildGoModule {
            name = "docman";
            # In 'nix develop', we don't need a copy of the source tree
            # in the Nix store.
            src = ././source;

            # This hash locks the dependencies of this package. It is
            # necessary because of how Go requires network access to resolve
            # VCS.  See https://www.tweag.io/blog/2021-03-04-gomod2nix/ for
            # details. Normally one can build with a fake sha256 and rely on native Go
            # mechanisms to tell you what the hash should be or determine what
            # it should be "out-of-band" with other tooling (eg. gomod2nix).
            # To begin with it is recommended to set this, but one must
            # remeber to bump this hash when your dependencies change.
            #vendorSha256 = pkgs.lib.fakeSha256;

            vendorSha256 = "sha256-XdB+u94Rqsb29jVs4miyOq1NEYaVJHWFXg6QebFJzNQ=";
            
            # "-X release.version=$version -X release.build=$(due --iso-8601 | tr -d "-" )"
            
            ldflags = [
                 "-X release.version=${version}"
                 "-X release.build=${buildDate}"
                      ];


            meta = with nixpkgs.legacyPackages.${system}.lib; {
                description = "docman is a document management tool";
                homepage = "https://gitlab.schukai.com/oss/utilities/documentation-manager";
                license = licenses.mit;
                maintainers = with maintainers; [ "schukai GmbH" ];
              };    

          };
        });
      
      # Add dependencies that are only needed for development
      devShells = forAllSystems (system:
        let 
          pkgs = nixpkgsFor.${system};
        in
        {
          default = pkgs.mkShell {
            buildInputs = with pkgs; [ go gopls gotools go-tools ];
          };
        });

      # The default package for 'nix build'. This makes sense if the
      # flake provides only one package or there is a clear "main"
      # package.
      defaultPackage = forAllSystems (system: self.packages.${system}.docman);
    };
}
